install.py

changeset 6495
6e73d31af3af
parent 6476
d13d573c2da4
child 6500
0373580fc86c
--- a/install.py	Sun Sep 09 19:30:54 2018 +0200
+++ b/install.py	Mon Sep 10 18:15:10 2018 +0200
@@ -373,20 +373,21 @@
     os.chmod(dst, 0o644)
 
 
-def wrapperName(dname, wfile):
+def wrapperNames(dname, wfile):
     """
     Create the platform specific name for the wrapper script.
     
     @param dname name of the directory to place the wrapper into
     @param wfile basename (without extension) of the wrapper script
-    @return the name of the wrapper script
+    @return the names of the wrapper scripts
     """
     if sys.platform.startswith("win"):
-        wname = dname + "\\" + wfile + ".bat"
+        wnames = (dname + "\\" + wfile + ".cmd",
+                  dname + "\\" + wfile + ".bat")
     else:
-        wname = dname + "/" + wfile
+        wnames = (dname + "/" + wfile, )
 
-    return wname
+    return wnames
 
 
 def createPyWrapper(pydir, wfile, isGuiScript=True):
@@ -414,7 +415,7 @@
     
     # all kinds of Windows systems
     if sys.platform.startswith("win"):
-        wname = wfile + marker + ".bat"
+        wname = wfile + marker + ".cmd"
         if isGuiScript:
             wrapper = \
                 '''@echo off\n''' \
@@ -645,9 +646,9 @@
             dirs.append(platBinDirOld)
         for rem_wname in rem_wnames:
             for d in dirs:
-                rwname = wrapperName(d, rem_wname)
-                if os.path.exists(rwname):
-                    os.remove(rwname)
+                for rwname in wrapperNames(d, rem_wname):
+                    if os.path.exists(rwname):
+                        os.remove(rwname)
         
         # Cleanup our config file(s)
         for name in ['eric6config.py', 'eric6config.pyc', 'eric6.pth']:
@@ -373,20 +373,21 @@
     """
-    Create the platform specific name for the wrapper script.
+    Create the platform specific names for the wrapper script.
     
     @param dname name of the directory to place the wrapper into

eric ide

mercurial